#!/bin/bash

# installhosts.sh
# version 1.0 (2013-10-26)
# by BitFume (bitfume.com)

# Description
# Replaces the system hosts file with the one in the same folder as this script. The old hosts file is renamed "hosts_previous". A "hosts_default" file is also copied to the system hosts folder, just in case (it holds the system default host values).

# Requirements
# The included hosts and hosts_default sample files require Mac OS X 10.3, because they contains IPv6 entries. IPv6 is supported in 10.1, but only enabled by default in 10.3.

# Instructions
# 1) Create a new hosts file and name it "hosts".
# 2) Place it in the same folder as this script.
# 3) Run this script to install the new hosts file.

# Troubleshooting
# If your hosts file is damaged or lost, restore it by using "Go to Folder..." to get to "etc/hosts", and create a text file named "hosts" with the following contents (be sure to remove the leading # and space characters):
# 127.0.0.1    localhost
# 255.255.255.255    broadcasthost
# ::1             localhost
# fe80::1%lo0    localhost

# Get permission to update hosts file
sudo echo 'Updating hosts file...' || (echo 'Error: no permission to update hosts file.' && exit 1);

# Start up
HOSTSFROM=$(dirname "$0")"/hosts"
HOSTSTO="/etc/hosts"
HOSTSDEFAULTFROM=$(dirname "$0")"/hosts_default"
HOSTSDEFAULTTO="/etc/hosts_default"
HOSTSBACKUPTO="/etc/hosts_previous"
if [ ! -f "$HOSTSFROM" ]; then
	echo 'Error: replacement hosts file not found.' && exit 1;
fi

# Save backup copy of hosts file
sudo cp -f "$HOSTSTO" "$HOSTSBACKUPTO" || echo 'Warning: unable to save backup of current hosts file ("etc/hosts_previous").';

# Replace old hosts file with new one
sudo cp -f "$HOSTSFROM" "$HOSTSTO" || (echo 'Error: unable to update hosts file ("etc/hosts").' && exit 1);

# Save a copy of the system default file, if possible
if [ -f "$HOSTSDEFAULTFROM" ]; then
	sudo cp -f "$HOSTSDEFAULTFROM" "$HOSTSDEFAULTTO" || echo 'Warning: unable to save backup of default system hosts file ("etc/hosts_default").';
else
	echo 'Warning: unable to save backup of default system hosts file ("etc/hosts_default").';
fi

# Clear DNS cache
sudo dscacheutil -flushcache || echo 'Warning: unable to clear DNS cache. Please restart for the new host data to take effect.';

# Finish up
echo 'Hosts file updated.' && exit 0;